==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ResponsiveStateExitedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateExitedEventArgsDescription } from "./ResponsiveStateExitedEventArgsDescription";
/**
 * @hidden
 */
export let ResponsiveStateExitedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ResponsiveStateExitedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ResponsiveStateExitedEventArgsDescriptionMetadata.a == null) {
                ResponsiveStateExitedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ResponsiveStateExitedEventArgsDescriptionMetadata.c(ResponsiveStateExitedEventArgsDescriptionMetadata.a);
            }
            if (a.j(ResponsiveStateExitedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ResponsiveStateExitedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ResponsiveStateExitedEventArgsDescriptionMetadata.b(a);
            a.aa("ResponsiveStateExitedEventArgs", () => new ResponsiveStateExitedEventArgsDescription());
            a.z("ResponsiveStateExitedEventArgs", ResponsiveStateExitedEventArgsDescriptionMetadata.a);
        }
    }
    ResponsiveStateExitedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ResponsiveStateExitedEventArgsDescriptionMetadata, 'ResponsiveStateExitedEventArgsDescriptionMetadata');
    ResponsiveStateExitedEventArgsDescriptionMetadata.a = null;
    return ResponsiveStateExitedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ResponsiveStateExitedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateExitedEventArgsDescription } from "./ResponsiveStateExitedEventArgsDescription";
/**
 * @hidden
 */
export let ResponsiveStateExitedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ResponsiveStateExitedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ResponsiveStateExitedEventArgsDescriptionMetadata.a == null) {
                ResponsiveStateExitedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ResponsiveStateExitedEventArgsDescriptionMetadata.c(ResponsiveStateExitedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ResponsiveStateExitedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ResponsiveStateExitedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ResponsiveStateExitedEventArgsDescriptionMetadata.b(a);
            a.ac("ResponsiveStateExitedEventArgs", () => new ResponsiveStateExitedEventArgsDescription());
            a.ab("ResponsiveStateExitedEventArgs", ResponsiveStateExitedEventArgsDescriptionMetadata.a);
        }
    }
    ResponsiveStateExitedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ResponsiveStateExitedEventArgsDescriptionMetadata, 'ResponsiveStateExitedEventArgsDescriptionMetadata');
    ResponsiveStateExitedEventArgsDescriptionMetadata.a = null;
    return ResponsiveStateExitedEventArgsDescriptionMetadata;
})();
